@@ -41,9 +41,9 @@
 "_llikWeibull", "_llikWeibullDshape", "_llikWeibullDscale", "_llikGamma", 
 "_llikGammaDshape", "_llikGammaDrate", "_llikCauchy", "_llikCauchyDlocation", 
 "_llikCauchyDscale"), type = c("linCmtA_p", "linCmtB_p", "rxode2i_fn2", 
-"rxode2i_rxbinom", "rxode2i_rxbinom", "rxode2i_rxbinom", "rxode2i_fn2", 
-"rxode2i_fn", "rxode2i_fn", "rxode2i_fn2", "rxode2i_ifn", "rxode2i_fn2", 
-"rxode2i_fn2", "rxode2i_ifn", "rxode2i_fn", "rxode2i_fn2", "rxode2i_fn2", 
+"rxode2i_rxbinom", "rxode2i_rxbinom", "rxode2i_rxbinom", "rxode2_fn2", 
+"rxode2_fn", "rxode2_fn", "rxode2_fn2", "rxode2_ifn", "rxode2_fn2", 
+"rxode2_fn2", "rxode2_ifn", "rxode2_fn", "rxode2_fn2", "rxode2_fn2", 
 "rxode2i2_fn2", "rxode2i2_ribinom", "rxode2i2_ribinom", "rxode2i2_ribinom", 
 "rxode2i2_fn2", "rxode2i2_fn", "rxode2i2_fn", "rxode2i2_fn2", 
 "rxode2i2_ifn", "rxode2i2_fn2", "rxode2i2_fn2", "rxode2i2_ifn", 
