@@ -1,4 +1,3 @@
-
 #pragma once
 #define STRICT_R_HEADERS
 #ifndef __rxode2_H__
@@ -28,8 +27,8 @@
 #include <stdint.h>    // for uint64_t rather than unsigned long long
 
 #ifndef __RXODE2PTR_H__  // directly refer to abi need to be excluded
-#define getAdvan(idx) ind->solve + (op->neq + op->nlin)*(idx) + op->neq
-#define getSolve(idx) ind->solve + (op->neq + op->nlin)*(idx)
+#define getSolve(idx) ind->solve + (op->neq)*(idx)
+#define getAdvan(idx) ind->solve + op->linOffset + op->neq*(idx)
 #endif
 
 #ifdef _isrxode2_
@@ -89,7 +88,7 @@ rx_solving_options *getRxOp(rx_solve *rx);
 SEXP rxode2_df(int doDose, int doTBS);
 SEXP rxode2_par_df(void);
 
-void rxOptionsIniEnsure(int mx);
+void rxOptionsIniEnsure(int mx, int cores);
 
 void rxUpdateFuns(SEXP trans);
 
@@ -490,10 +489,12 @@ static inline double dabs2(double x) {
   extern "C" rx_solve rx_global;
   extern "C" rx_solving_options op_global;
   extern "C" rx_solving_options_ind *inds_global;
+  extern "C" rx_solving_options_ind *inds_thread;
 #else
   extern rx_solve rx_global;
   extern rx_solving_options op_global;
   extern rx_solving_options_ind *inds_global;
+  extern rx_solving_options_ind *inds_thread;
 #endif
 
 
