@@ -1,5 +1,208 @@
 rxTest({
 
+  test_that("test lag-time information parsing", {
+
+    m1 <- rxode2parse("KA=2.94E-01;
+    CL=1.86E+01;
+    V2=4.02E+01;
+    Q=1.05E+01;
+    V3=2.97E+02;
+    Kin=1;
+    Kout=1;
+    EC50=200;
+    fdepot = 1;
+    durDepot = 8;
+    rateDepot = 1250;
+    C2 = centr/V2;
+    C3 = peri/V3;
+    d/dt(depot) =-KA*depot;
+    f(depot) = fdepot
+    dur(depot) = durDepot
+    rate(depot) = rateDepot
+    alag(depot) = alagDepot
+    d/dt(centr) = KA*depot - CL*C2 - Q*C2 + Q*C3;
+    d/dt(peri)  =                    Q*C2 - Q*C3;
+    d/dt(eff)  = Kin - Kout*(1-C2/(EC50+C2))*eff;
+    eff(0) = 1")
+    expect_equal(m1$alag, 1L)
+
+    m1 <- rxode2parse("KA=2.94E-01;
+    CL=1.86E+01;
+    V2=4.02E+01;
+    Q=1.05E+01;
+    V3=2.97E+02;
+    Kin=1;
+    Kout=1;
+    EC50=200;
+    fdepot = 1;
+    durDepot = 8;
+    rateDepot = 1250;
+    C2 = centr/V2;
+    C3 = peri/V3;
+    d/dt(depot) =-KA*depot;
+    f(depot) = fdepot
+    dur(depot) = durDepot
+    rate(depot) = rateDepot
+    d/dt(centr) = KA*depot - CL*C2 - Q*C2 + Q*C3;
+    alag(centr) = alagDepot
+    d/dt(peri)  =                    Q*C2 - Q*C3;
+    d/dt(eff)  = Kin - Kout*(1-C2/(EC50+C2))*eff;
+    eff(0) = 1")
+    expect_equal(m1$alag, 2L)
+
+    m1 <- rxode2parse("KA=2.94E-01;
+    CL=1.86E+01;
+    V2=4.02E+01;
+    Q=1.05E+01;
+    V3=2.97E+02;
+    Kin=1;
+    Kout=1;
+    EC50=200;
+    fdepot = 1;
+    durDepot = 8;
+    rateDepot = 1250;
+    C2 = centr/V2;
+    C3 = peri/V3;
+    d/dt(depot) =-KA*depot;
+    f(depot) = fdepot
+    dur(depot) = durDepot
+    rate(depot) = rateDepot
+    d/dt(centr) = KA*depot - CL*C2 - Q*C2 + Q*C3;
+    d/dt(peri)  =                    Q*C2 - Q*C3;
+    alag(peri) = alagDepot
+    d/dt(eff)  = Kin - Kout*(1-C2/(EC50+C2))*eff;
+    eff(0) = 1")
+    expect_equal(m1$alag, 3L)
+
+    m1 <- rxode2parse("KA=2.94E-01;
+    CL=1.86E+01;
+    V2=4.02E+01;
+    Q=1.05E+01;
+    V3=2.97E+02;
+    Kin=1;
+    Kout=1;
+    EC50=200;
+    fdepot = 1;
+    durDepot = 8;
+    rateDepot = 1250;
+    C2 = centr/V2;
+    C3 = peri/V3;
+    d/dt(depot) =-KA*depot;
+    f(depot) = fdepot
+    dur(depot) = durDepot
+    rate(depot) = rateDepot
+    d/dt(centr) = KA*depot - CL*C2 - Q*C2 + Q*C3;
+    d/dt(peri)  =                    Q*C2 - Q*C3;
+    d/dt(eff)  = Kin - Kout*(1-C2/(EC50+C2))*eff;
+    alag(eff) = alagDepot
+    eff(0) = 1")
+    expect_equal(m1$alag, 4L)
+
+    m1 <- rxode2parse("KA=2.94E-01;
+    CL=1.86E+01;
+    V2=4.02E+01;
+    Q=1.05E+01;
+    V3=2.97E+02;
+    Kin=1;
+    Kout=1;
+    EC50=200;
+    fdepot = 1;
+    durDepot = 8;
+    rateDepot = 1250;
+    C2 = centr/V2;
+    C3 = peri/V3;
+    d/dt(depot) =-KA*depot;
+    f(depot) = fdepot
+    dur(depot) = durDepot
+    rate(depot) = rateDepot
+    alag(depot) = alagDepot
+    d/dt(centr) = KA*depot - CL*C2 - Q*C2 + Q*C3;
+    alag(centr) = alagDepot
+    d/dt(peri)  =                    Q*C2 - Q*C3;
+    alag(peri) = alagDepot
+    d/dt(eff)  = Kin - Kout*(1-C2/(EC50+C2))*eff;
+    alag(eff) = alagDepot
+    eff(0) = 1")
+    expect_equal(m1$alag, 1:4)
+
+    m1 <- rxode2parse("KA=2.94E-01;
+    CL=1.86E+01;
+    V2=4.02E+01;
+    Q=1.05E+01;
+    V3=2.97E+02;
+    Kin=1;
+    Kout=1;
+    EC50=200;
+    fdepot = 1;
+    durDepot = 8;
+    rateDepot = 1250;
+    C2 = centr/V2;
+    C3 = peri/V3;
+    d/dt(depot) =-KA*depot;
+    f(depot) = fdepot
+    dur(depot) = durDepot
+    rate(depot) = rateDepot
+    alag(depot) = alagDepot
+    d/dt(centr) = KA*depot - CL*C2 - Q*C2 + Q*C3;
+    d/dt(peri)  =                    Q*C2 - Q*C3;
+    alag(peri) = alagDepot
+    d/dt(eff)  = Kin - Kout*(1-C2/(EC50+C2))*eff;
+    alag(eff) = alagDepot
+    eff(0) = 1")
+    expect_equal(m1$alag, c(1L, 3:4))
+
+    m1 <- rxode2parse("KA=2.94E-01;
+    CL=1.86E+01;
+    V2=4.02E+01;
+    Q=1.05E+01;
+    V3=2.97E+02;
+    Kin=1;
+    Kout=1;
+    EC50=200;
+    fdepot = 1;
+    durDepot = 8;
+    rateDepot = 1250;
+    C2 = centr/V2;
+    C3 = peri/V3;
+    d/dt(depot) =-KA*depot;
+    f(depot) = fdepot
+    dur(depot) = durDepot
+    rate(depot) = rateDepot
+    d/dt(centr) = KA*depot - CL*C2 - Q*C2 + Q*C3;
+    alag(centr) = alagDepot
+    d/dt(peri)  =                    Q*C2 - Q*C3;
+    alag(peri) = alagDepot
+    d/dt(eff)  = Kin - Kout*(1-C2/(EC50+C2))*eff;
+    alag(eff) = alagDepot
+    eff(0) = 1")
+    expect_equal(m1$alag, 2:4)
+
+    m1 <- rxode2parse("KA=2.94E-01;
+    CL=1.86E+01;
+    V2=4.02E+01;
+    Q=1.05E+01;
+    V3=2.97E+02;
+    Kin=1;
+    Kout=1;
+    EC50=200;
+    fdepot = 1;
+    durDepot = 8;
+    rateDepot = 1250;
+    C2 = centr/V2;
+    C3 = peri/V3;
+    d/dt(depot) =-KA*depot;
+    f(depot) = fdepot
+    dur(depot) = durDepot
+    rate(depot) = rateDepot
+    d/dt(centr) = KA*depot - CL*C2 - Q*C2 + Q*C3;
+    d/dt(peri)  =                    Q*C2 - Q*C3;
+    d/dt(eff)  = Kin - Kout*(1-C2/(EC50+C2))*eff;
+    eff(0) = 1")
+    expect_equal(m1$alag, integer(0))
+
+  })
+
+
   et <- et(1:10)
   et$b <- 1:10
 
