@@ -1,13 +1,11 @@
 rxTest({
   test_that("nopred ui", {
-
     pheno2 <- function() {
       ini({
-        tcl <- log(0.008) # typical value of clearance
-        tv <-  log(0.6)   # typical value of volume
-        ## var(eta.cl)
+        tcl <- log(0.008)
+        tv <-  log(0.6)
         eta.cl + eta.v ~ c(1,
-                           0.01, 1) ## cov(eta.cl, eta.v), var(eta.v)
+                           0.01, 1)
       })
       model({
         cl <- exp(tcl + eta.cl) # individual value of clearance
@@ -25,6 +23,5 @@ rxTest({
     et <- et(amt=1) %>% et(1:20) %>% et(id=1:20)
 
     expect_error(rxWithSeed(42, rxSolve(mod, et)), NA)
-
   })
 })
