@@ -1,9 +1,9 @@
 rxTest({
   test_that("CMT translation matches input", {
-    filename <- test_path("433.qs")
+    filename <- test_path("433.qs2")
     skip_if_not(file.exists(filename))
 
-    lst <- qs::qread(filename)
+    lst <- qs2::qs_read(filename)
 
     rx <- rxode2({
       cmt(parent)
