@@ -26,8 +26,6 @@ rxTest({
       expect_equal(testPipeQuote(t),
                    list(quote(a <- x), quote(b <- y)))
 
-
-
       tmp <- list(tmp="d/dt(depot)")
 
       expect_equal(testPipeQuote(tmp$tmp),
@@ -37,12 +35,14 @@ rxTest({
 
       expect_equal(testPipeQuote(tmp$tmp$tmp),
                    list(quote(d/dt(depot))))
+
     })
 
     test_that("equivalent drop statements", {
 
       expect_equal(.changeDropNullLine(quote(a <- NULL)),
                    quote(-a))
+
       expect_equal(.changeDropNullLine(quote(a ~ NULL)),
                    quote(-a))
       expect_equal(.changeDropNullLine(str2lang("a = NULL")),
@@ -107,18 +107,23 @@ rxTest({
     })
 
     test_that("test fix/unfix for eta", {
+
       expect_equal(testPipeQuote(a~fix),
                    list(quote(a<-fix)))
       expect_equal(testPipeQuote(a~unfix),
                    list(quote(a<-unfix)))
+
     })
 
     test_that("test as formula", {
+
       expect_equal(testPipeQuote(as.formula(a~b)),
                    list(quote(a~b)))
+
     })
 
     test_that("test of standard quoting of piping arguments", {
+
       expect_equal(testPipeQuote(-ka, tka=0.5, {
         tv = 3
         tcl = 10
@@ -492,6 +497,7 @@ rxTest({
            quote(eta.v ~ 0.2),
            quote(eta.v + eta.cl ~ unfix(cor(sd(0.3, 0.02, 0.1)))))
       )
+
     })
 
     one.compartment <- function() {
@@ -518,6 +524,7 @@ rxTest({
     f <- rxode2(one.compartment)
 
     test_that("Model Line from Expression, assign", {
+
       expect_equal(.getModelLineFromExpression(quote(ka), f), 1L)
       expect_equal(.getModelLineFromExpression(quote(d/dt(depot)), f), 4L)
 
@@ -557,6 +564,7 @@ rxTest({
     f <- rxode2(one.compartment)
 
     test_that("Model Line from Expression, lower case f()", {
+
       expect_equal(.getModelLineFromExpression(quote(ka), f), 1L)
       expect_equal(.getModelLineFromExpression(quote(d/dt(depot)), f), 4L)
 
@@ -596,6 +604,7 @@ rxTest({
     f <- rxode2(one.compartment)
 
     test_that("Model Line from Expression, upper case F()", {
+
       expect_equal(.getModelLineFromExpression(quote(ka), f), 1L)
       expect_equal(.getModelLineFromExpression(quote(d/dt(depot)), f), 4L)
 
@@ -607,6 +616,7 @@ rxTest({
 
       expect_equal(.getModelLineFromExpression(quote(rate(depot)), f), -4L)
       expect_equal(.getModelLineFromExpression(quote(dur(depot)), f), -4L)
+
     })
 
     one.compartment <- function() {
@@ -634,6 +644,7 @@ rxTest({
     f <- rxode2(one.compartment)
 
     test_that("Model Line from Expression, lag()", {
+
       expect_equal(.getModelLineFromExpression(quote(ka), f), 1L)
       expect_equal(.getModelLineFromExpression(quote(d/dt(depot)), f), 4L)
 
@@ -645,6 +656,7 @@ rxTest({
 
       expect_equal(.getModelLineFromExpression(quote(rate(depot)), f), -4L)
       expect_equal(.getModelLineFromExpression(quote(dur(depot)), f), -4L)
+
     })
 
     one.compartment <- function() {
@@ -672,6 +684,7 @@ rxTest({
     f <- rxode2(one.compartment)
 
     test_that("Model Line from Expression, alag()", {
+
       expect_equal(.getModelLineFromExpression(quote(ka), f), 1L)
       expect_equal(.getModelLineFromExpression(quote(d/dt(depot)), f), 4L)
 
@@ -683,6 +696,7 @@ rxTest({
 
       expect_equal(.getModelLineFromExpression(quote(rate(depot)), f), -4L)
       expect_equal(.getModelLineFromExpression(quote(dur(depot)), f), -4L)
+
     })
 
     one.compartment <- function() {
@@ -710,6 +724,7 @@ rxTest({
     f <- rxode2(one.compartment)
 
     test_that("Model Line from Expression, rate()", {
+
       expect_equal(.getModelLineFromExpression(quote(ka), f), 1L)
       expect_equal(.getModelLineFromExpression(quote(d/dt(depot)), f), 4L)
 
@@ -721,6 +736,7 @@ rxTest({
 
       expect_equal(.getModelLineFromExpression(quote(rate(depot)), f), 6L)
       expect_equal(.getModelLineFromExpression(quote(dur(depot)), f), -4L)
+
     })
 
     one.compartment <- function() {
@@ -748,6 +764,7 @@ rxTest({
     f <- rxode2(one.compartment)
 
     test_that("Model Line from Expression, dur()", {
+
       expect_equal(.getModelLineFromExpression(quote(ka), f), 1L)
       expect_equal(.getModelLineFromExpression(quote(d/dt(depot)), f), 4L)
 
@@ -761,6 +778,7 @@ rxTest({
       expect_equal(.getModelLineFromExpression(quote(dur(depot)), f), 6L)
 
       expect_equal(.getModelLineFromExpression(quote(not), f), NA_integer_)
+
     })
 
     # look at duplicate lines
@@ -789,6 +807,7 @@ rxTest({
     f <- rxode2(one.compartment)
 
     test_that("Model Line from Expression, duplicate d/dt(depot)", {
+
       expect_equal(.getModelLineFromExpression(quote(ka), f), 1L)
 
       expect_equal(.getModelLineFromExpression(quote(d/dt(depot)), f), NULL)
@@ -803,6 +822,7 @@ rxTest({
       expect_equal(.getModelLineFromExpression(quote(dur(depot)), f), -5L)
 
       expect_equal(.getModelLineFromExpression(quote(not), f), NA_integer_)
+
     })
 
     # look at duplicate lines
@@ -832,6 +852,7 @@ rxTest({
     f <- rxode2(one.compartment)
 
     test_that("Model Line from Expression, duplicate f(depot)", {
+
       expect_equal(.getModelLineFromExpression(quote(ka), f), 1L)
       expect_equal(.getModelLineFromExpression(quote(d/dt(depot)), f), 4L)
 
@@ -845,6 +866,7 @@ rxTest({
       expect_equal(.getModelLineFromExpression(quote(dur(depot)), f), -4L)
 
       expect_equal(.getModelLineFromExpression(quote(not), f), NA_integer_)
+
     })
 
     # look at duplicate lag()
@@ -874,6 +896,7 @@ rxTest({
     f <- rxode2(one.compartment)
 
     test_that("Model Line from Expression, duplicate f(depot)", {
+
       expect_equal(.getModelLineFromExpression(quote(ka), f), 1L)
       expect_equal(.getModelLineFromExpression(quote(d/dt(depot)), f), 4L)
 
@@ -890,6 +913,7 @@ rxTest({
       expect_equal(.getModelLineFromExpression(quote(cp), f), 8L)
 
       expect_equal(.getModelLineFromExpression(quote(cp), f, TRUE), 9L)
+
     })
 
     one.compartment <- function() {
@@ -927,6 +951,7 @@ rxTest({
     }
 
     test_that("simple ini piping, uncorrelated model", {
+
       testEst(f, "tka", -Inf, 0.45, Inf, FALSE)
       testEst(f %>% ini(tka=0.5), "tka", -Inf, 0.5, Inf, FALSE)
       testEst(f %>% ini(tka=fix), "tka", -Inf, 0.45, Inf, TRUE)
@@ -979,6 +1004,7 @@ rxTest({
         testEst(f %>% ini(eta.cl+eta.v~unfix(cor(sd(0.3,0.02,0.1)))), "(eta.cl,eta.v)", -Inf, 0.1 * 0.3 * 0.02, Inf, FALSE),
         regexp="unfix.*eta.cl"), regexp="unfix.*eta.v"
         )
+
     })
 
     one.compartment <- function() {
@@ -1005,6 +1031,7 @@ rxTest({
     f <- rxode2(one.compartment)
 
     test_that("simple ini piping, correlated model", {
+
       testEst(f, "tka", -Inf, 0.45, Inf, FALSE)
       testEst(f %>% ini(tka=0.5), "tka", -Inf, 0.5, Inf, FALSE)
       testEst(f %>% ini(tka=fix), "tka", -Inf, 0.45, Inf, TRUE)
@@ -1049,6 +1076,7 @@ rxTest({
         testEst(f %>% ini(eta.cl+eta.v~unfix(cor(sd(0.3,0.02,0.1)))), "(eta.cl,eta.v)", -Inf, 0.1 * 0.3 * 0.02, Inf, FALSE),
         regexp="unfix.*eta.cl"), regexp="unfix.*eta.v"
         )
+
     })
 
     one.compartment <- function() {
@@ -1075,6 +1103,7 @@ rxTest({
     f <- rxode2(one.compartment)
 
     test_that("simple ini piping, fixed correlated model", {
+
       testEst(f, "tka", -Inf, 0.45, Inf, FALSE)
       testEst(f %>% ini(tka=0.5), "tka", -Inf, 0.5, Inf, FALSE)
       testEst(f %>% ini(tka=fix), "tka", -Inf, 0.45, Inf, TRUE)
@@ -1176,11 +1205,14 @@ rxTest({
     }
 
     test_that("update: Test Base model", {
+
       testUi(f, c("tka", "tcl", "tv", "eta.ka", "eta.cl", "eta.v", "add.err"),
              "matt", c(tka = 0.45, tcl = 1, tv = 3.45, eta.ka = 0.6, eta.cl = 0.3, eta.v = 0.1, add.err = 0.7))
+
     })
 
     test_that("UI updates work correctly", {
+
       # context("update: Multiple component change with c()")
       testUi(
         f %>% update(tka = 4, cl = exp(tcl), ka = exp(tka), c(tcl = 3, tv = 4)),
@@ -1271,10 +1303,12 @@ rxTest({
         })
       )
       expect_s3_class(.ui, "rxUi")
+
     })
 
     # piping looks through parent environments
     test_that("Looks through prior frames for the correct object", {
+
       fit <- rxode2(one.compartment)
       fits <- lapply(seq(-1, -0.1, 0.1), function(kainit) {
         suppressMessages(
@@ -1288,6 +1322,7 @@ rxTest({
           rxode2(update(fit, tka = matt))
         )
       }))
+
     })
 
     one.compartment <- function() {
@@ -1314,6 +1349,7 @@ rxTest({
     f <- rxode2(one.compartment)
 
     test_that("piping works for correlations #1", {
+
       testUi(f %>% ini(eta.ka + eta.cl ~ c(
         0.2,
         0.01, 0.2
@@ -1323,22 +1359,23 @@ rxTest({
       values = c(
         tka = 0.45, tcl = 1, tv = 3.45, eta.ka = 0.2, eta.cl = 0.2, eta.v = 0.1, add.err = 0.7,
         `(eta.ka,eta.cl)` = 0.01
-      )
-      )
+      ))
+
     })
 
     test_that("piping works for correlations #2", {
+
       suppressMessages(
         expect_error(
           f %>%
             ini(eta.ka + eta.matt ~ c(0.2,
                                       0.01, 0.2)
-                )
-        )
-      )
+                )))
+
     })
 
     test_that("piping works for correlations #3", {
+
       testUi(
         f %>% update(eta.ka + eta.cl ~ c(
           0.2,
@@ -1347,23 +1384,22 @@ rxTest({
         c("tka", "tcl", "tv", "eta.ka", "eta.cl", "eta.v", "add.err", "(eta.ka,eta.cl)"),
         "matt", c(
           tka = 0.45, tcl = 1, tv = 3.45, eta.ka = 0.2, eta.cl = 0.2, eta.v = 0.1, add.err = 0.7,
-          `(eta.ka,eta.cl)` = 0.01
-        )
-      )
+          `(eta.ka,eta.cl)` = 0.01))
+
     })
 
     test_that("piping works for correlations #4", {
+
       suppressMessages(
         expect_error(
           f %>%
             update(eta.ka + eta.matt ~ c(0.2,
-                                         0.01, 0.2)
-                   )
-        )
-      )
+                                         0.01, 0.2))))
+
     })
 
     test_that("expected piping errors", {
+
       f <- function() {
         ini({
           ke <- 0.5
@@ -1380,11 +1416,12 @@ rxTest({
       f <- rxode2::rxode2(f)
 
       suppressMessages(
-        expect_error(f %>% model(ipre ~ add(add.sd)) %>% ini(add.sd=sqrt(0.1)), NA)
-      )
+        expect_error(f %>% model(ipre ~ add(add.sd)) %>% ini(add.sd=sqrt(0.1)), NA))
+
     })
 
     test_that("new ipre", {
+
       f <- function() {
         ini({
           tke <- 0.5
@@ -1410,9 +1447,11 @@ rxTest({
       f2 <- trans(f)
 
       expect_true(!any(f2$iniDf$name %in% c("f2")))
+
     })
 
     test_that("piping looks in the right environment for variables with fix()", {
+
       f <- function() {
         ini({
           tke <- 0.5
@@ -1453,6 +1492,7 @@ rxTest({
 
         intke <- 5
         f %>% ini(tke=fix(intke))
+
       }
 
       suppressMessages(
@@ -1463,9 +1503,11 @@ rxTest({
       expect_equal(tmp$iniDf[tmp$iniDf$name == "tke","est"], 5)
 
       expect_false(any(ls() == "intke"))
+
     })
 
     test_that("invalid model pipe (more arguments than expected) throws an error", {
+
       f <- function() {
         ini({
           tke <- 0.5
@@ -1483,9 +1525,11 @@ rxTest({
       }
 
       expect_error(f %>% model(ipre~prop(f2,f3,c)))
+
     })
 
     test_that("Add an eta to a model that does not have an eta will work", {
+
       ocmt <- function() {
         ini({
           tka <- exp(0.45)
@@ -1508,12 +1552,12 @@ rxTest({
         expect_error(
           ocmt %>%
             model(ka <- exp(tka + eta.ka)),
-          NA
-        )
-      )
+          NA))
+
     })
 
     test_that("Add covariate to model works", {
+
       ocmt <- function() {
         ini({
           tka <- exp(0.45)
@@ -1537,15 +1581,12 @@ rxTest({
         expect_error(
           ocmt %>%
             model(ka <- exp(tka + covKa * wt + eta.ka)),
-          NA
-        )
-      )
+          NA))
 
       suppressMessages(
         tmp <-
           ocmt %>%
-          model(ka <- exp(tka + covKaWt * wt + eta.ka))
-      )
+          model(ka <- exp(tka + covKaWt * wt + eta.ka)))
       expect_equal(tmp$allCovs, "wt")
 
       expect_true("covKaWt" %in% tmp$iniDf$name)
@@ -1555,8 +1596,7 @@ rxTest({
       suppressMessages(
         tmp <-
           ocmt %>%
-          model(ka <- exp(covKaWt * wt + eta.ka))
-      )
+          model(ka <- exp(covKaWt * wt + eta.ka)))
 
       expect_equal(tmp$allCovs, "wt")
       expect_true("covKaWt" %in% tmp$iniDf$name)
@@ -1566,15 +1606,16 @@ rxTest({
       suppressMessages(
         tmp <-
           tmp %>%
-          model(ka <- exp(tka + covKaWt * wt + eta.ka))
-      )
+          model(ka <- exp(tka + covKaWt * wt + eta.ka)))
       expect_equal(tmp$allCovs, "wt")
       expect_true("covKaWt" %in% tmp$iniDf$name)
       expect_true("tka" %in% tmp$iniDf$name)
       expect_true("eta.ka" %in% tmp$iniDf$name)
+
     })
 
     test_that("Appending or pre-pending items to a model works", {
+
       ocmt <- function() {
         ini({
           tka <- exp(0.45)
@@ -1614,9 +1655,11 @@ rxTest({
       f2 <- f %>% model(f2 <- 3 * 2, append=NA)
       expect_true("f2" %in% f2$mv0$lhs)
       expect_equal(f2$lstExpr[[1]], quote(f2 <- 3 * 2))
+
     })
 
     test_that("ini promotion works", {
+
       ocmt <- function() {
         ini({
           tka <- 0.45
@@ -1642,16 +1685,14 @@ rxTest({
 
       # now promote tv
       suppressMessages(
-        f2 <- f %>% ini(tv=0.5)
-      )
+        f2 <- f %>% ini(tv=0.5))
       expect_equal(f2$allCovs, c("eta.ka", "eta.cl", "eta.v"))
       expect_equal(f2$theta, c(tka=0.45, tcl=1, add.sd=0.7, tv=0.5))
       expect_equal(f2$omega, NULL)
 
       # now promote eta.ka
       suppressMessages(
-        f3 <- f2 %>% ini(eta.ka ~ 0.01)
-      )
+        f3 <- f2 %>% ini(eta.ka ~ 0.01))
 
       expect_equal(f3$allCovs, c("eta.cl", "eta.v"))
       expect_equal(f3$theta, c(tka=0.45, tcl=1, add.sd=0.7, tv=0.5))
@@ -1660,8 +1701,7 @@ rxTest({
       # now promote a correlation between eta.cl and eta.v
       suppressMessages(
         f4 <- f2 %>% ini(eta.cl + eta.v ~ c(1,
-                                            0.01, 1))
-      )
+                                            0.01, 1)))
       expect_equal(f4$allCovs, "eta.ka")
       expect_equal(f4$theta, c(tka=0.45, tcl=1, add.sd=0.7, tv=0.5))
 
@@ -1671,8 +1711,7 @@ rxTest({
       # Now promote independent eta block
       suppressMessages(
         f5 <- f3 %>% ini(eta.cl + eta.v ~ c(1,
-                                            0.01, 1))
-      )
+                                            0.01, 1)))
       expect_length(f5$allCovs, 0)
       expect_equal(f5$theta, c(tka=0.45, tcl=1, add.sd=0.7, tv=0.5))
       expect_equal(f5$omega, lotri(eta.ka ~ 0.01,
@@ -1683,16 +1722,17 @@ rxTest({
       suppressMessages(
         f6 <- f3 %>% ini(eta.ka + eta.cl + eta.v ~ c(1,
                                                      0.01, 1,
-                                                     -0.01, 0.01, 1))
-      )
+                                                     -0.01, 0.01, 1)))
       expect_length(f6$allCovs, 0)
       expect_equal(f6$theta, c(tka=0.45, tcl=1, add.sd=0.7, tv=0.5))
       expect_equal(f6$omega, lotri(eta.ka + eta.cl + eta.v ~ c(1,
                                                                0.01, 1,
                                                                -0.01, 0.01, 1)))
+
     })
 
     test_that("Ignoring auto-selected parameter types work", {
+
       ocmt <- function() {
         ini({
           tka <- exp(0.45)
@@ -1712,8 +1752,7 @@ rxTest({
       }
 
       suppressWarnings(
-        f <- rxode2(ocmt)
-      )
+        f <- rxode2(ocmt))
 
       expect_equal(f$allCovs, character(0))
       expect_equal(f$theta, c(tka=exp(0.45), tcl=exp(1), add.sd=0.7))
@@ -1731,8 +1770,7 @@ rxTest({
         f2 <-
           f %>%
           model(ka <- tka * exp(eta.ka), auto=FALSE) %>%
-          ini(eta.ka ~ 0.02)
-      ))
+          ini(eta.ka ~ 0.02)))
       expect_equal(f2$allCovs, character(0))
       expect_equal(f2$theta, c(tka=exp(0.45), tcl=exp(1), add.sd=0.7))
       expect_equal(f2$omega, lotri(eta.v ~ 0.01,
@@ -1752,9 +1790,11 @@ rxTest({
       expect_equal(f2$allCovs, character(0))
       expect_equal(f2$theta, c(tka=exp(0.45), tcl=exp(1), add.sd=0.7, tv=0.2))
       expect_equal(f2$omega, lotri(eta.v ~ 0.01))
+
     })
 
     test_that("Ignoring auto-selected parameter types work", {
+
       ocmt <- function() {
         ini({
           tka <- exp(0.45)
@@ -1784,9 +1824,11 @@ rxTest({
       )
       expect_equal(f2$theta, f1$theta)
       expect_equal(f2$omega, f1$omega)
+
     })
 
     test_that("Pre-declaring list of covariates works", {
+
       rxSetCovariateNamesForPiping(c("WT","HT", "TC"))
 
       # Note this is case sensitive
@@ -1830,10 +1872,12 @@ rxTest({
       )
       expect_true("cov_C" %in% mod$iniDf$name)
       expect_true("TC" %in% mod$iniDf$name)
+
     })
   })
 
   test_that("eff(0) piping should work", {
+
     mod1 <- rxode2({
       C2 <- centr/V2
       C3 <- peri/V3
@@ -1853,9 +1897,8 @@ rxTest({
               Q=1.05E+01,  V3=2.97E+02, # peripheral
               Kin=1, Kout=1, EC50=200) %>%
           model(eff(0) <- 1),
-        NA
-      )
-    )
+        NA))
+
   })
 
 
